@@ -65,6 +65,14 @@ struct _GVfsBackendMtp
 
   gboolean android_extension;
   gboolean get_partial_object_capability;
+
+#ifdef HAVE_LIBMTP_1_1_5
+  GThreadPool *event_pool;
+#endif
+#ifdef HAVE_LIBMTP_1_1_12
+  GThread *event_thread;
+  gboolean event_completed;
+#endif
 };
 
 struct _GVfsBackendMtpClass
